from setuptools import setup

# Ensure that Cython was installed
# noinspection PyUnresolvedReferences
import Cython

setup(
    name='build-system-no-backend',
    version='0.1.0',
    install_requires=[],
)
